Examples
========


- `Fitting a minimal radiative model`_
- `Fitting IC emission from an electron distribution`_
- `Fitting Synchrotron and IC emission from an electron distribution`_
- `Additional model expressions`_
- `Crab Nebula SSC model`_

Fitting a minimal radiative model 
---------------------------------

.. literalinclude:: ../examples/RXJ1713_IC_minimal.py
    :language: python

Fitting IC emission from an electron distribution
-------------------------------------------------

.. literalinclude:: ../examples/RXJ1713_IC.py
    :language: python

Fitting Synchrotron and IC emission from an electron distribution
-----------------------------------------------------------------

.. literalinclude:: ../examples/RXJ1713_SynIC.py
    :language: python

Additional model expressions
----------------------------

.. literalinclude:: ../examples/model_examples.py
    :language: python


.. _CrabSSC:

Crab Nebula SSC model
---------------------

.. literalinclude:: ../examples/CrabNebula_SynSSC.py
    :language: python
